==> orchestra-api-4.2.0-sources.jar: org/ow2/orchestra/facade/def/impl/CompensationHandlerDefinitionImpl.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.def.impl;

import org.ow2.orchestra.facade.def.CompensationHandlerDefinition;
import org.ow2.orchestra.facade.runtime.ActivityType;

/**
 * @author S. Ali Tokmen
 */
public class CompensationHandlerDefinitionImpl extends BaseFCTDefinitionImpl implements CompensationHandlerDefinition {

  private static final long serialVersionUID = 738582345472098443L;

  public CompensationHandlerDefinitionImpl(final CompensationHandlerDefinition CompensationHandlerDefinition) {
    super(CompensationHandlerDefinition);
  }

  public CompensationHandlerDefinition copy() {
    return new CompensationHandlerDefinitionImpl(this);
  }

  public ActivityType getType() {
    return ActivityType.COMPENSATION_HANDLER;
  }

}

==> orchestra-api-4.6.1-sources.jar: org/ow2/orchestra/facade/def/impl/CompensationHandlerDefinitionImpl.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.def.impl;

import org.ow2.orchestra.facade.def.CompensationHandlerDefinition;
import org.ow2.orchestra.facade.runtime.ActivityType;

/**
 * @author S. Ali Tokmen
 */
public class CompensationHandlerDefinitionImpl extends BaseFCTDefinitionImpl implements CompensationHandlerDefinition {

  private static final long serialVersionUID = 738582345472098443L;

  public CompensationHandlerDefinitionImpl(final CompensationHandlerDefinition compensationHandlerDefinition) {
    super(compensationHandlerDefinition);
  }

  public CompensationHandlerDefinition copy() {
    return new CompensationHandlerDefinitionImpl(this);
  }

  public ActivityType getType() {
    return ActivityType.COMPENSATION_HANDLER;
  }

}
